/**
 *  Copyright (c) 2014 Keang. All Rights Reserved.
 */

package test.driver;

import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.assertNull;
import static org.junit.Assert.assertTrue;

import java.util.Calendar;

import org.junit.Before;
import org.junit.BeforeClass;
import org.junit.Test;

import uk.co.keang.callerid.driver.CallType;
import uk.co.keang.callerid.driver.CallerIDMessage;
import uk.co.keang.callerid.driver.WhyNoNumber;

/**
 * Test the caller ID message decoder
 *
 * @author Keang
 * @version 1.0 - 15 Jan 2014
 */
public class CallerIDMessageTest
{

private static byte[] msgSimple;
private static byte[] msgNoNumber;

/**
 * @throws java.lang.Exception
 */
@BeforeClass
public static void setUpBeforeClass() throws Exception
    {
    msgSimple = new byte[] {(byte)128, 34, 17, 1, 1, 1, 8, 49, 48, 49, 48, 48, 51, 51, 48, 2, 10, 49, 50, 51, 52, 53, 54, 55, 56, 57, 48, 7, 7, 80, 69, 84, 69, 82, 32, 82, (byte)161};
    msgNoNumber = new byte[] {(byte)128, 25, 17, 1, 1, 1, 8, 49, 48, 49, 48, 48, 51, 51, 48, 4, 1, 0x50, 7, 7, 80, 69, 84, 69, 82, 32, 82, (byte)110};
    }

private CallerIDMessage testSimple;
private CallerIDMessage testNoNumber;

/**
 * @throws java.lang.Exception
 */
@Before
public void setUp() throws Exception
    {
    testSimple = new CallerIDMessage(msgSimple);
    testNoNumber = new CallerIDMessage(msgNoNumber);
    }

/**
 * Test method for {@link uk.co.keang.callerid.driver.CallerIDMessage#hasNumber()}.
 */
@Test
public void testHasNumber()
    {
    assertTrue(testSimple.hasNumber());
    assertFalse(testNoNumber.hasNumber());
    }

/**
 * Test method for {@link uk.co.keang.callerid.driver.CallerIDMessage#getName()}.
 */
@Test
public void testGetName()
    {
    assertNotNull(testSimple.getName());
    assertTrue(testSimple.getName().equals("PETER R"));
    }

/**
 * Test method for {@link uk.co.keang.callerid.driver.CallerIDMessage#getNumber()}.
 */
@Test
public void testGetNumber()
    {
    assertNotNull(testSimple.getNumber());
    assertTrue(testSimple.getNumber().equals("1234567890"));

    assertNull(testNoNumber.getNumber());
    }

/**
 * Test method for {@link uk.co.keang.callerid.driver.CallerIDMessage#getDate()}.
 */
@Test
public void testGetDate()
    {
    assertNotNull(testSimple.getDate());
    Calendar cal = Calendar.getInstance();
    cal.setTime(testSimple.getDate());

    assertTrue(cal.get(Calendar.MONTH) == 10-1);
    assertTrue(cal.get(Calendar.DAY_OF_MONTH) == 10);
    assertTrue(cal.get(Calendar.HOUR) == 3);
    assertTrue(cal.get(Calendar.MINUTE) == 30);
    }

/**
 * Test method for {@link uk.co.keang.callerid.driver.CallerIDMessage#getWhyNoNumber()}.
 */
@Test
public void testGetWhyNoNumber()
    {
    assertNull(testSimple.getWhyNoNumber());

    assertNotNull(testNoNumber.getWhyNoNumber());
    assertTrue(testNoNumber.getWhyNoNumber() == WhyNoNumber.WITHHELD);
    }

/**
 * Test method for {@link uk.co.keang.callerid.driver.CallerIDMessage#getCallType()}.
 */
@Test
public void testGetCallType()
    {
    assertNotNull(testSimple.getCallType());
    assertTrue(testSimple.getCallType() == CallType.VOICE);
    }

}
