/**
 *  Copyright (c) 2014 Keang. All Rights Reserved.
 *
 * The CallerIDEvent class is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The CallerIDEvent class is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
 * more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with the CallerIDEvent class.  If not, see <http://www.gnu.org/licenses/>.
 */

package uk.co.keang.callerid.driver;

import java.util.Date;
import java.util.EventObject;

/**
 * A caller ID event generated when there is an incoming call.
 * The source object is of type CallerIDMessage which contains details about the
 * incoming call.
 * This event also has convenience methods for the commonly required details to save
 * having to directly access the source object
 *
 * @author Keang
 * @version 1.0 - 15 Jan 2014
 */
public class CallerIDEvent extends EventObject
{
private static final long serialVersionUID = 8992079443097977053L;
private final String telNumber;
private final Date callTime;

/**
 * Create the event object
 *
 * @param dec The decoder
 */
public CallerIDEvent(CallerIDMessage dec)
    {
    super(dec);

    telNumber = ((CallerIDMessage)source).getNumber();
    callTime = ((CallerIDMessage)source).getDate();
    }

/**
 * true if the message contains a number
 *
 * @return true if there is a phone number
 */
public boolean hasNumber()
    {
    return telNumber != null;
    }

/**
 * Gets the callers telephone number if there is one
 *
 * @return the callers telephone number or null
 */
public String getNumber()
    {
    return telNumber;
    }

/**
 * Gets the callers date and time
 *
 * @return the callers date and time or null
 */
public Date getDate()
    {
    return callTime;
    }

@Override
public String toString()
    {
    return source == null ? telNumber + ": " + callTime : source.toString();
    }
}
